require 'spec_helper'

describe OnPayRuClient::Client do
  class Payment < Struct.new(:id, :amount, :email); end

  let(:success_url) { "http://site.com/payments/success" }
  let(:fail_url) { "http://site.com/payments/failure" }
  let(:onpayru) { OnPayRuClient::Client.new('a', 'b', 'c', success_url, fail_url) }

  let(:payment) { Payment.new('1', '100.0', 'user@example.com') }

  it 'gets initialization params' do
    expect(onpayru.login).to eq('a')
    expect(onpayru.key).to eq('b')
    expect(onpayru.url).to eq('c')
  end

  it 'returns payment url' do
    expect(onpayru.get_url(payment.id, payment.amount, payment.email)).to\
      eq("http://secure.onpay.ru/pay/#{onpayru.login}?pay_mode=fix&price=#{payment.amount}&pay_for=#{payment.id}&user_email=#{payment.email}&url_success=#{onpayru.success_url}&url_fail=#{onpayru.fail_url}")
  end

  it 'checks check md5' do
    md5 = Digest::MD5.hexdigest("check;#{payment.id};#{payment.amount};RUR;0;#{onpayru.key}").upcase
    expect(md5).to eq("C24217C61CB831C1028F52DA63C691CC")
  end

  it 'checks pay md5' do
    md5 = Digest::MD5.hexdigest("pay;#{payment.id};1;#{payment.amount};RUR;0").upcase
    expect(md5).to eq("4164761F594B072ABDDD1492C648F2E0")
  end

  it 'returns check request' do
    md5 = Digest::MD5.hexdigest("check;#{payment.id};#{payment.amount};RUR;0;#{onpayru.key}").upcase
    expect(onpayru.check("check", payment.id, payment.amount, "RUR", 0)).to\
      eq("<result><code>0</code><pay_for>#{payment.id}</pay_for><comment>OK</comment><md5>#{md5}</md5></result>")
  end

  it 'returns pay request' do
    md5 = Digest::MD5.hexdigest("pay;#{payment.id};1;#{payment.amount};RUR;0").upcase
    expect(onpayru.pay("pay", payment.id, 1, payment.id, payment.amount, "RUR", 0)).to\
      eq("<result><code>0</code><comment>OK</comment><onpay_id>1</onpay_id><pay_for>1</pay_for><order_id>1</order_id><md5>ABA5F57C42FD5AD6FF49AD690CBC08BE</md5></result>")
  end
end
